@@ -2,6 +2,7 @@ from __future__ import absolute_import, division, print_function
 
 # flake8: noqa
 
+from stripe.api_resources.error_object import ErrorObject, OAuthErrorObject
 from stripe.api_resources.list_object import ListObject
 
 from stripe.api_resources import checkout
@@ -44,6 +45,7 @@ from stripe.api_resources.invoice_item import InvoiceItem
 from stripe.api_resources.invoice_line_item import InvoiceLineItem
 from stripe.api_resources.issuer_fraud_record import IssuerFraudRecord
 from stripe.api_resources.login_link import LoginLink
+from stripe.api_resources.mandate import Mandate
 from stripe.api_resources.order import Order
 from stripe.api_resources.order_return import OrderReturn
 from stripe.api_resources.payment_intent import PaymentIntent
@@ -64,9 +66,6 @@ from stripe.api_resources.source_transaction import SourceTransaction
 from stripe.api_resources.subscription import Subscription
 from stripe.api_resources.subscription_item import SubscriptionItem
 from stripe.api_resources.subscription_schedule import SubscriptionSchedule
-from stripe.api_resources.subscription_schedule_revision import (
-    SubscriptionScheduleRevision,
-)
 from stripe.api_resources.tax_id import TaxId
 from stripe.api_resources.tax_rate import TaxRate
 from stripe.api_resources.three_d_secure import ThreeDSecure
