@@ -45,6 +45,7 @@ OBJECT_CLASSES = {
     api_resources.issuing.Dispute.OBJECT_NAME: api_resources.issuing.Dispute,
     api_resources.issuing.Transaction.OBJECT_NAME: api_resources.issuing.Transaction,
     api_resources.LoginLink.OBJECT_NAME: api_resources.LoginLink,
+    api_resources.Mandate.OBJECT_NAME: api_resources.Mandate,
     api_resources.Order.OBJECT_NAME: api_resources.Order,
     api_resources.OrderReturn.OBJECT_NAME: api_resources.OrderReturn,
     api_resources.PaymentIntent.OBJECT_NAME: api_resources.PaymentIntent,
@@ -71,7 +72,6 @@ OBJECT_CLASSES = {
     api_resources.Subscription.OBJECT_NAME: api_resources.Subscription,
     api_resources.SubscriptionItem.OBJECT_NAME: api_resources.SubscriptionItem,
     api_resources.SubscriptionSchedule.OBJECT_NAME: api_resources.SubscriptionSchedule,
-    api_resources.SubscriptionScheduleRevision.OBJECT_NAME: api_resources.SubscriptionScheduleRevision,
     api_resources.TaxId.OBJECT_NAME: api_resources.TaxId,
     api_resources.TaxRate.OBJECT_NAME: api_resources.TaxRate,
     api_resources.terminal.ConnectionToken.OBJECT_NAME: api_resources.terminal.ConnectionToken,
